/*
 * Copyright 2016 University of Chicago
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "globus_gridftp_server_s3_base.h"

static
S3Status
globus_l_s3_recv_multipart_abort_properties(
    const S3ResponseProperties         *properties,
    void                               *callback_data);

static
void
globus_l_s3_recv_multipart_abort_complete(
    S3Status                            status,
    const S3ErrorDetails               *error_details,
    void                               *callback_data);

/**
 * @brief Abort the multipart transfer associated with transfer_state
 */
globus_result_t
globus_i_s3_recv_multipart_abort(
    globus_i_s3_transfer_t             *transfer_state)
{
    globus_result_t                     result = GLOBUS_SUCCESS;
    GlobusS3Enter();


    GlobusS3Info("REST: op=%p S3_abort_multipart_upload(id=%s) try=%d\n",
                (void *) transfer_state->op,
                transfer_state->multipart_id,
                transfer_state->retries);

    S3_abort_multipart_upload(
            &transfer_state->bucket_context,
            transfer_state->key,
            transfer_state->multipart_id,
            &(S3AbortMultipartUploadHandler)
            {
                .responseHandler.propertiesCallback
                                      = globus_l_s3_recv_multipart_abort_properties,
                .responseHandler.completeCallback
                                      = globus_l_s3_recv_multipart_abort_complete
            });
    result = transfer_state->result;

    GlobusS3ExitResult(result);
    return result;
}
/* globus_i_s3_recv_multipart_abort() */

static
S3Status
globus_l_s3_recv_multipart_abort_properties(
    const S3ResponseProperties         *properties,
    void                               *callback_data)
{
    S3Status                            status = S3StatusOK;

    GlobusS3Enter();
    GlobusS3ExitStatus(status);

    return status;
}
/* globus_l_s3_recv_multipart_abort_properties() */

static
void
globus_l_s3_recv_multipart_abort_complete(
    S3Status                            status,
    const S3ErrorDetails               *error_details,
    void                               *callback_data)
{
    GlobusS3Enter();

    // Ignore errors here

    GlobusS3Exit();

    return;
}
/* globus_i_s3_recv_multipart_abort_complete() */
// vim: ft=c:
